<?php
/**
 * @file
 *  Defines tokens for news_client.
 */

/**
 * Implements hook_token_info().
 */
function news_client_token_info() {
  $info = array();
  
  $info['tokens']['node']['news_client_body_summary'] = array(
    'name' => t('News Client:Body Summary'),
    'description' => t('Body summary for the News Client Cached Article.'),
  );
  
  $info['tokens']['node']['news_client_featured_image_url'] = array(
    'name' => t('News Client:Featured Image URL'),
    'description' => t('Featured Image URL for the News Client Cached Article.'),
  );
  
  $info['tokens']['node']['news_client_featured_image_alt'] = array(
    'name' => t('News Client:Featured Image Alt'),
    'description' => t('Featured Image alt text for the News Client Cached Article.'),
  );
  
  return $info;
}

/**
 * Implements hook_tokens().
 */
function news_client_tokens($type, $tokens, array $data = array(), array $options = array()) {
  $replacements = array();
  $sanitize = !empty($options['sanitize']);
  
  if ($type == 'node' && !empty($data['node'])) {
    $node = $data['node'];
    
    if ($node->type == 'news_client_cached_article') {
      try {
        $wrapper = entity_metadata_wrapper('node', $node);
        
        foreach ($tokens as $name => $original) {
          switch ($name) {
            case 'news_client_body_summary':
              $summary = $wrapper->news_client_body->summary->value();
              $summary = strip_tags($summary);
              $summary = trim($summary);
              
              if (empty($summary)) {
                $body = $wrapper->news_client_body->value->value();
                $body = strip_tags($body);
                $summary = text_summary($body, NULL, 200);
              }
              
              $replacements[$original] = $summary;
              break;
              
            case 'news_client_featured_image_url' :
              $image_json = $wrapper->news_client_image_json->value();
              $image_array = json_decode($image_json, TRUE);
              $image_data = array_shift($image_array);
              
              $replacements[$original] = isset($image_data['url']) ? $image_data['url'] : '';
              break;
              
            case 'news_client_featured_image_alt' :
              $image_json = $wrapper->news_client_image_json->value();
              $image_array = json_decode($image_json, TRUE);
              $image_data = array_shift($image_array);
            
              $replacements[$original] = isset($image_data['alt']) ? $image_data['alt'] : '';
              break;
          }
        }
      }
      catch (Exception $e) {
        _news_client_entitymetadatawrapper_exception($e);
      }
    }
  }
  
  return $replacements;
}
